"""

:copyright: Copyright since 2006 by Oliver Schoenborn, all rights reserved.
:license: BSD, see LICENSE.txt for details.

"""

from pubsub import setuparg1
from pubsub.py2and3 import print_

import console_senders as senders
import console_listeners


def run():
    print_('Using "arg1" messaging protocol of pubsub v3')

    senders.doSomething1()
    senders.doSomething2()


if __name__ == '__main__':
    run()



"""

:copyright: Copyright since 2006 by Oliver Schoenborn, all rights reserved.
:license: BSD, see LICENSE.txt for details.

"""

from pubsub import pub


def doSomething1():
    pub.sendMessage('topic_1.subtopic_11', ('message for subtopic 11', 'other message', 123))


def doSomething2():
    pub.sendMessage('topic_1', 'message for topic 1')
    pub.sendMessage('topic_2.subtopic_21', 'message for subtopic 2')





"""

:copyright: Copyright since 2006 by Oliver Schoenborn, all rights reserved.
:license: BSD, see LICENSE.txt for details.

"""

from pubsub import pub

def doSomething1():
    pub.sendMessage('topic_1.subtopic_11',
        msg='message for subtopic 11', msg2='other message', extra=123)


def doSomething2():
    pub.sendMessage('topic_1', msg='message for topic 1')
    pub.sendMessage('topic_2.subtopic_21', msg='message for subtopic 2')





"""
Uses topic definition provider for kwargs messaging protocol. Compare with
main_arg1.py which shows example using arg1 messaging protocol:
kwargs protocol provides for message data self-documentation and more
robustness (pubsub can determine if message data missing or unknown due
to type, etc).

Experiment by changing arg1_topics.py and looking at the output tree
in kwargs_topics_out.py.

:copyright: Copyright since 2006 by Oliver Schoenborn, all rights reserved.
:license: BSD, see LICENSE.txt for details.
"""

from pubsub import pub
from pubsub.py2and3 import print_

import notifhandle
import exchandle

import kwargs_topics

#***** actual application **********

print_('Using "kwargs" messaging protocol of pubsub v3')

try:
    print_('------- init ----------')

    pub.addTopicDefnProvider( kwargs_topics, pub.TOPIC_TREE_FROM_CLASS )
    pub.setTopicUnspecifiedFatal()

    import kwargs_listeners
    import kwargs_senders as senders

    print_('-----------------------')
    senders.doSomething1()
    senders.doSomething2()

    print_('------- done ----------')

    print_('Exporting topic tree to', kwargs_topics.__name__)
    pub.exportTopicTreeSpec('kwargs_topics_out')

except Exception:
    import traceback
    traceback.print_exc()
    print_(pub.exportTopicTreeSpec())

print_('------ exiting --------')